summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorKatja Marttila <katja.marttila@qt.io>2017-08-21 13:33:46 +0300
committerKatja Marttila <katja.marttila@qt.io>2017-08-21 14:44:35 +0300
commit1fe36e54d5bd75bc0a403218966f8046a66718da (patch)
tree3153e54f94d2c0aaecfe0a60dc651c1da8f473fc
parentad00a64d86be127e61016e02c78795c98a8c7982 (diff)
parent776c09b3307463fb3c3d8da7054439a28c2c9ad0 (diff)
Merge remote-tracking branch 'origin/3.0' into master
Conflicts: dist/config/config.xml dist/packages/org.qtproject.ifw.binaries/meta/package.xml dist/packages/org.qtproject.ifw/meta/package.xml installerfw.pri Change-Id: Ib2ab53321b599eb2e8b1e6e23be2ba507a948c5c
-rw-r--r--Changelog8
-rw-r--r--dist/config/config.xml2
-rw-r--r--src/libs/installer/consumeoutputoperation.h1
-rw-r--r--src/libs/installer/createdesktopentryoperation.h1
-rw-r--r--src/libs/installer/createlinkoperation.h1
-rw-r--r--src/libs/installer/createshortcutoperation.h1
-rw-r--r--src/libs/installer/downloadfiletask.cpp2
-rw-r--r--src/libs/installer/environmentvariablesoperation.h1
-rw-r--r--src/libs/installer/globalsettingsoperation.h1
-rw-r--r--src/libs/installer/licenseoperation.h1
-rw-r--r--src/libs/installer/linereplaceoperation.h1
-rw-r--r--src/libs/installer/replaceoperation.h1
-rw-r--r--src/libs/installer/selfrestartoperation.h1
-rw-r--r--src/libs/installer/settingsoperation.h1
-rw-r--r--src/libs/kdtools/updateoperations.h7
-rw-r--r--tools/binarycreator/binarycreator.cpp45
16 files changed, 52 insertions, 23 deletions
diff --git a/Changelog b/Changelog
index 6d9908a2f..d97dfc8e1 100644
--- a/Changelog
+++ b/Changelog
@@ -1,3 +1,11 @@
+3.0.1
+- Fix install type if --online-only passed to binarycreator
+- Fix install fail if there are missing repositories
+- Fix Component Name visibility in maintenancetool
+- Adminauthorization freeze fixed under unix (QTIFW-934)
+- Enable high-DPI scaling (QTBUG-61122)
+- Fix maintenance tool update with silentUpdate (QTIFW-976)
+
3.0.0
- Change required Qt version, minimum version is now 5.6.2.
- Clarify the add/remove components string to make it clearer
diff --git a/dist/config/config.xml b/dist/config/config.xml
index e896b963c..a0e049792 100644
--- a/dist/config/config.xml
+++ b/dist/config/config.xml
@@ -2,7 +2,7 @@
<Installer>
<Name>Qt Installer Framework</Name>
<Title>Qt Installer Framework 3.1.81</Title>
- <Version>1.0.0</Version>
+ <Version>3.1.81</Version>
<Publisher>Qt Project</Publisher>
<ProductUrl>http://qt-project.org</ProductUrl>
<Watermark>watermark.png</Watermark>
diff --git a/src/libs/installer/consumeoutputoperation.h b/src/libs/installer/consumeoutputoperation.h
index 714fe51ee..a1f8a09ff 100644
--- a/src/libs/installer/consumeoutputoperation.h
+++ b/src/libs/installer/consumeoutputoperation.h
@@ -35,6 +35,7 @@ namespace QInstaller {
class INSTALLER_EXPORT ConsumeOutputOperation : public Operation
{
+ Q_DECLARE_TR_FUNCTIONS(QInstaller::ConsumeOutputOperation)
public:
explicit ConsumeOutputOperation(PackageManagerCore *core);
diff --git a/src/libs/installer/createdesktopentryoperation.h b/src/libs/installer/createdesktopentryoperation.h
index 2744172f0..793d1db16 100644
--- a/src/libs/installer/createdesktopentryoperation.h
+++ b/src/libs/installer/createdesktopentryoperation.h
@@ -35,6 +35,7 @@ namespace QInstaller {
class INSTALLER_EXPORT CreateDesktopEntryOperation : public Operation
{
+ Q_DECLARE_TR_FUNCTIONS(QInstaller::CreateDesktopEntryOperation)
public:
explicit CreateDesktopEntryOperation(PackageManagerCore *core);
~CreateDesktopEntryOperation();
diff --git a/src/libs/installer/createlinkoperation.h b/src/libs/installer/createlinkoperation.h
index 22a2a1f7a..2e4ece9aa 100644
--- a/src/libs/installer/createlinkoperation.h
+++ b/src/libs/installer/createlinkoperation.h
@@ -35,6 +35,7 @@ namespace QInstaller {
class INSTALLER_EXPORT CreateLinkOperation : public Operation
{
+ Q_DECLARE_TR_FUNCTIONS(QInstaller::CreateLinkOperation)
public:
explicit CreateLinkOperation(PackageManagerCore *core);
diff --git a/src/libs/installer/createshortcutoperation.h b/src/libs/installer/createshortcutoperation.h
index 84aec10df..dc2ac6ddb 100644
--- a/src/libs/installer/createshortcutoperation.h
+++ b/src/libs/installer/createshortcutoperation.h
@@ -35,6 +35,7 @@ namespace QInstaller {
class INSTALLER_EXPORT CreateShortcutOperation : public Operation
{
+ Q_DECLARE_TR_FUNCTIONS(QInstaller::CreateShortcutOperation)
public:
explicit CreateShortcutOperation(PackageManagerCore *core);
diff --git a/src/libs/installer/downloadfiletask.cpp b/src/libs/installer/downloadfiletask.cpp
index c6cef2183..2c99e04e1 100644
--- a/src/libs/installer/downloadfiletask.cpp
+++ b/src/libs/installer/downloadfiletask.cpp
@@ -257,6 +257,7 @@ void Downloader::onError(QNetworkReply::NetworkError error)
const Data &data = *m_downloads[reply];
//Do not throw error if Updates.xml not found. The repository might be removed
//with RepositoryUpdate in Updates.xml later.
+ //: %2 is a sentence describing the error
if (data.taskItem.source().contains(QLatin1String("Updates.xml"), Qt::CaseInsensitive)) {
qDebug() << QString::fromLatin1("Network error while downloading '%1': %2.").arg(
data.taskItem.source(), reply->errorString());
@@ -265,7 +266,6 @@ void Downloader::onError(QNetworkReply::NetworkError error)
TaskException(tr("Network error while downloading '%1': %2.").arg(
data.taskItem.source(), reply->errorString())));
}
- //: %2 is a sentence describing the error
} else {
//: %1 is a sentence describing the error
m_futureInterface->reportException(
diff --git a/src/libs/installer/environmentvariablesoperation.h b/src/libs/installer/environmentvariablesoperation.h
index 1f4ad4cb2..3c5252bc6 100644
--- a/src/libs/installer/environmentvariablesoperation.h
+++ b/src/libs/installer/environmentvariablesoperation.h
@@ -35,6 +35,7 @@ namespace QInstaller {
class INSTALLER_EXPORT EnvironmentVariableOperation : public Operation
{
+ Q_DECLARE_TR_FUNCTIONS(QInstaller::EnvironmentVariableOperation)
public:
explicit EnvironmentVariableOperation(PackageManagerCore *core);
diff --git a/src/libs/installer/globalsettingsoperation.h b/src/libs/installer/globalsettingsoperation.h
index 67d416ecf..fe5d14edb 100644
--- a/src/libs/installer/globalsettingsoperation.h
+++ b/src/libs/installer/globalsettingsoperation.h
@@ -36,6 +36,7 @@ namespace QInstaller {
class QSettingsWrapper;
class INSTALLER_EXPORT GlobalSettingsOperation : public Operation
{
+ Q_DECLARE_TR_FUNCTIONS(QInstaller::GlobalSettingsOperation)
public:
explicit GlobalSettingsOperation(PackageManagerCore *core);
diff --git a/src/libs/installer/licenseoperation.h b/src/libs/installer/licenseoperation.h
index 06e3fa777..49b885565 100644
--- a/src/libs/installer/licenseoperation.h
+++ b/src/libs/installer/licenseoperation.h
@@ -35,6 +35,7 @@ namespace QInstaller {
class INSTALLER_EXPORT LicenseOperation : public Operation
{
+ Q_DECLARE_TR_FUNCTIONS(QInstaller::LicenseOperation)
public:
explicit LicenseOperation(PackageManagerCore *core);
diff --git a/src/libs/installer/linereplaceoperation.h b/src/libs/installer/linereplaceoperation.h
index 8e310fe84..d15e11fef 100644
--- a/src/libs/installer/linereplaceoperation.h
+++ b/src/libs/installer/linereplaceoperation.h
@@ -35,6 +35,7 @@ namespace QInstaller {
class INSTALLER_EXPORT LineReplaceOperation : public Operation
{
+ Q_DECLARE_TR_FUNCTIONS(QInstaller::LineReplaceOperation)
public:
explicit LineReplaceOperation(PackageManagerCore *core);
diff --git a/src/libs/installer/replaceoperation.h b/src/libs/installer/replaceoperation.h
index ca81db47c..0d2783ab6 100644
--- a/src/libs/installer/replaceoperation.h
+++ b/src/libs/installer/replaceoperation.h
@@ -35,6 +35,7 @@ namespace QInstaller {
class INSTALLER_EXPORT ReplaceOperation : public Operation
{
+ Q_DECLARE_TR_FUNCTIONS(QInstaller::ReplaceOperation)
public:
explicit ReplaceOperation(PackageManagerCore *core);
diff --git a/src/libs/installer/selfrestartoperation.h b/src/libs/installer/selfrestartoperation.h
index 9acd46490..7adccd183 100644
--- a/src/libs/installer/selfrestartoperation.h
+++ b/src/libs/installer/selfrestartoperation.h
@@ -35,6 +35,7 @@ namespace QInstaller {
class INSTALLER_EXPORT SelfRestartOperation : public Operation
{
+ Q_DECLARE_TR_FUNCTIONS(QInstaller::SelfRestartOperation)
public:
explicit SelfRestartOperation(PackageManagerCore *core);
diff --git a/src/libs/installer/settingsoperation.h b/src/libs/installer/settingsoperation.h
index b8d02589e..0b94ea015 100644
--- a/src/libs/installer/settingsoperation.h
+++ b/src/libs/installer/settingsoperation.h
@@ -35,6 +35,7 @@ namespace QInstaller {
class INSTALLER_EXPORT SettingsOperation : public Operation
{
+ Q_DECLARE_TR_FUNCTIONS(QInstaller::SettingsOperation)
public:
explicit SettingsOperation(PackageManagerCore *core);
diff --git a/src/libs/kdtools/updateoperations.h b/src/libs/kdtools/updateoperations.h
index cb8b133e6..b13a42559 100644
--- a/src/libs/kdtools/updateoperations.h
+++ b/src/libs/kdtools/updateoperations.h
@@ -35,6 +35,7 @@ namespace KDUpdater {
class KDTOOLS_EXPORT CopyOperation : public UpdateOperation
{
+ Q_DECLARE_TR_FUNCTIONS(KDUpdater::CopyOperation)
public:
explicit CopyOperation(QInstaller::PackageManagerCore *core = 0);
~CopyOperation();
@@ -52,6 +53,7 @@ private:
class KDTOOLS_EXPORT MoveOperation : public UpdateOperation
{
+ Q_DECLARE_TR_FUNCTIONS(KDUpdater::MoveOperation)
public:
explicit MoveOperation(QInstaller::PackageManagerCore *core = 0);
~MoveOperation();
@@ -64,6 +66,7 @@ public:
class KDTOOLS_EXPORT DeleteOperation : public UpdateOperation
{
+ Q_DECLARE_TR_FUNCTIONS(KDUpdater::DeleteOperation)
public:
explicit DeleteOperation(QInstaller::PackageManagerCore *core = 0);
~DeleteOperation();
@@ -78,6 +81,7 @@ public:
class KDTOOLS_EXPORT MkdirOperation : public UpdateOperation
{
+ Q_DECLARE_TR_FUNCTIONS(KDUpdater::MkdirOperation)
public:
explicit MkdirOperation(QInstaller::PackageManagerCore *core = 0);
@@ -89,6 +93,7 @@ public:
class KDTOOLS_EXPORT RmdirOperation : public UpdateOperation
{
+ Q_DECLARE_TR_FUNCTIONS(KDUpdater::RmdirOperation)
public:
RmdirOperation(QInstaller::PackageManagerCore *core = 0);
@@ -100,6 +105,7 @@ public:
class KDTOOLS_EXPORT AppendFileOperation : public UpdateOperation
{
+ Q_DECLARE_TR_FUNCTIONS(KDUpdater::AppendFileOperation)
public:
explicit AppendFileOperation(QInstaller::PackageManagerCore *core = 0);
@@ -111,6 +117,7 @@ public:
class KDTOOLS_EXPORT PrependFileOperation : public UpdateOperation
{
+ Q_DECLARE_TR_FUNCTIONS(KDUpdater::PrependFileOperation)
public:
explicit PrependFileOperation(QInstaller::PackageManagerCore *core = 0);
diff --git a/tools/binarycreator/binarycreator.cpp b/tools/binarycreator/binarycreator.cpp
index b9497f533..361dbd3fa 100644
--- a/tools/binarycreator/binarycreator.cpp
+++ b/tools/binarycreator/binarycreator.cpp
@@ -154,34 +154,34 @@ static int assemble(Input input, const QInstaller::Settings &settings, const QSt
infoPList.open(QIODevice::WriteOnly);
QTextStream plistStream(&infoPList);
plistStream << QLatin1String("<?xml version=\"1.0\" encoding=\"UTF-8\"?>") << endl;
- plistStream << QLatin1String("<!DOCTYPE plist SYSTEM \"file://localhost/System/Library/DTDs"
- "/PropertyList.dtd\">") << endl;
- plistStream << QLatin1String("<plist version=\"0.9\">") << endl;
+ plistStream << QLatin1String("<!DOCTYPE plist PUBLIC \"-//Apple//DTD PLIST 1.0//EN\" "
+ "\"http://www.apple.com/DTDs/PropertyList-1.0.dtd\">") << endl;
+ plistStream << QLatin1String("<plist version=\"1.0\">") << endl;
plistStream << QLatin1String("<dict>") << endl;
- plistStream << QLatin1String(" <key>CFBundleIconFile</key>") << endl;
- plistStream << QLatin1String(" <string>") << iconTargetFile << QLatin1String("</string>")
+ plistStream << QLatin1String("\t<key>CFBundleIconFile</key>") << endl;
+ plistStream << QLatin1String("\t<string>") << iconTargetFile << QLatin1String("</string>")
<< endl;
- plistStream << QLatin1String(" <key>CFBundlePackageType</key>") << endl;
- plistStream << QLatin1String(" <string>APPL</string>") << endl;
- plistStream << QLatin1String(" <key>CFBundleGetInfoString</key>") << endl;
+ plistStream << QLatin1String("\t<key>CFBundlePackageType</key>") << endl;
+ plistStream << QLatin1String("\t<string>APPL</string>") << endl;
+ plistStream << QLatin1String("\t<key>CFBundleGetInfoString</key>") << endl;
#define QUOTE_(x) #x
#define QUOTE(x) QUOTE_(x)
- plistStream << QLatin1String(" <string>") << QLatin1String(QUOTE(IFW_VERSION_STR)) << ("</string>")
+ plistStream << QLatin1String("\t<string>") << QLatin1String(QUOTE(IFW_VERSION_STR)) << ("</string>")
<< endl;
#undef QUOTE
#undef QUOTE_
- plistStream << QLatin1String(" <key>CFBundleSignature</key>") << endl;
- plistStream << QLatin1String(" <string> ???? </string>") << endl;
- plistStream << QLatin1String(" <key>CFBundleExecutable</key>") << endl;
- plistStream << QLatin1String(" <string>") << fi.completeBaseName() << QLatin1String("</string>")
+ plistStream << QLatin1String("\t<key>CFBundleSignature</key>") << endl;
+ plistStream << QLatin1String("\t<string>\?\?\?\?</string>") << endl;
+ plistStream << QLatin1String("\t<key>CFBundleExecutable</key>") << endl;
+ plistStream << QLatin1String("\t<string>") << fi.completeBaseName() << QLatin1String("</string>")
<< endl;
- plistStream << QLatin1String(" <key>CFBundleIdentifier</key>") << endl;
- plistStream << QLatin1String(" <string>com.yourcompany.installerbase</string>") << endl;
- plistStream << QLatin1String(" <key>NOTE</key>") << endl;
- plistStream << QLatin1String(" <string>This file was generated by Qt Installer Framework.</string>")
+ plistStream << QLatin1String("\t<key>CFBundleIdentifier</key>") << endl;
+ plistStream << QLatin1String("\t<string>com.yourcompany.installerbase</string>") << endl;
+ plistStream << QLatin1String("\t<key>NOTE</key>") << endl;
+ plistStream << QLatin1String("\t<string>This file was generated by Qt Installer Framework.</string>")
<< endl;
- plistStream << QLatin1String(" <key>NSPrincipalClass</key>") << endl;
- plistStream << QLatin1String(" <string>NSApplication</string>") << endl;
+ plistStream << QLatin1String("\t<key>NSPrincipalClass</key>") << endl;
+ plistStream << QLatin1String("\t<string>NSApplication</string>") << endl;
plistStream << QLatin1String("</dict>") << endl;
plistStream << QLatin1String("</plist>") << endl;
@@ -797,8 +797,11 @@ int main(int argc, char **argv)
{
QSettings confInternal(tmpMetaDir + QLatin1String("/config/config-internal.ini")
, QSettings::IniFormat);
- // assume offline installer if there are no repositories
- offlineOnly |= settings.repositories().isEmpty();
+ // assume offline installer if there are no repositories and no
+ //--online-only not set
+ offlineOnly = offlineOnly | settings.repositories().isEmpty();
+ if (onlineOnly)
+ offlineOnly = !onlineOnly;
confInternal.setValue(QLatin1String("offlineOnly"), offlineOnly);
}